==> haskell-shakespeare-2.1.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shakespeare
version:              2.1.3
visibility:           public
id:                   shakespeare-2.1.3-Jr7HERzylqABop8C1hWBNO
key:                  shakespeare-2.1.3-Jr7HERzylqABop8C1hWBNO
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  f926cfc62dd8d73eb573f847289e1231
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.3-Jr7HERzylqABop8C1hWBNO
depends:
    aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5 base-4.17.2.1
    blaze-html-0.9.2.0-IKVhdom3eJ46byuPgdmCPo
    blaze-markup-0.8.3.0-43ndMyx4AoQ9NdwqsN7MSJ bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY ghc-prim-0.9.1
    parsec-3.1.16.1 process-1.6.18.0
    scientific-0.3.7.0-Kb5Gqy0LO2R6GqxRC9SGn9 template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx
    vector-0.13.2.0-BWMo7dqC00725tIPRLs4rJ

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.1.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shakespeare
version:              2.1.3
visibility:           public
id:                   shakespeare-2.1.3-IOO24I3FQngCwEOfxaKjDn
key:                  shakespeare-2.1.3-IOO24I3FQngCwEOfxaKjDn
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  7dad8499bd3c10a00a8c9985d925f9b9
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shakespeare-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.3-IOO24I3FQngCwEOfxaKjDn
depends:
    aeson-2.1.2.1-F9MXb1A8ug6GkYytoGh4jA base-4.17.2.1
    blaze-html-0.9.2.0-DAO4ZQIQS7qFbxwO9Jt8KP
    blaze-markup-0.8.3.0-7bGtt2mO8fS3E0RwSK0P9N bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY ghc-prim-0.9.1
    parsec-3.1.16.1 process-1.6.18.0
    scientific-0.3.7.0-IuEDgnpy5lN4JI5naZeXd4 template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kb1zmdIZFsX5Z4trT8w0xB
    vector-0.13.2.0-3KdUWUHYfVjDmpelwHDbn6

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
